# nn-zoo

![PyPI - Python Version](https://img.shields.io/pypi/pyversions/nn-zoo)
![PyPI - Version](https://img.shields.io/pypi/v/nn-zoo)
![PyPI - License](https://img.shields.io/pypi/l/nn-zoo)
![PyPI - Downloads](https://img.shields.io/pypi/dm/nn-zoo)

## Overview

This repository contains a collection reusable machine learning models and utilities. The goal is to provide a set of tools that can be easily integrated into other projects. The models are implemented using PyTorch and are designed to be easily extended and modified. Inspired by projects like [Hugging Face Transformers](https://github.com/huggingface/transformers) and [PyTorch Lightning](https://github.com/Lightning-AI/pytorch-lightning).

## Table of Contents

- [Overview](#overview)
- [Installation](#installation)
- [Contributing](#contributing)
- [License](#license)

## Installation

To install the package, run the following command:

```bash
pip install nn-zoo
```

## Contributing

Contributions are welcome! For bug reports or requests please submit an issue.
To install the package in development mode, run the following command:

```bash
git clone https://github.com/karanravindra/nn-zoo.git
cd nn-zoo
pip install -r dev-requirements.txt
```

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.
